==> title_cases-1.0.0.zip: title_cases/README.md <==
# Title Cases

The introduction summarizes the purpose and function of the project, and should
be concise (a brief paragraph or two). This introduction may be the same as the
first paragraph on the project page.

The purpose of this module is to simplify the display of node titles using a
language writing style guide such Associated Press (AP).

Apply a title case from a language style guide to selected content type page
titles. The Title Case module only alters the presentation display of the title
field and does not change the stored title field value.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/title_cases).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/title_cases).


## Table of contents (optional)

- Requirements
- Installation
- Configuration
- Troubleshooting
- Maintainers


## Requirements (required)

This module requires no modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration (required)

1. Enable the module at Administration > Extend.
1. Configure the Title Cases module at Administration > Configuration > System


## Troubleshooting (optional)

Displays a node title using a Title Case from a style guide after configuration.

Block titles (subject field) and View titles are not affected. However, this is
being considered for future development.

Drupal, browser, and other cache may need to be cleared.

## Maintainers (optional)

- Justin Christoffersen - [larsdesigns](https://www.drupal.org/u/larsdesigns)

==> title_cases-1.0.1.zip: title_cases/README.md <==
# Title Cases

The introduction summarizes the purpose and function of the project, and should
be concise (a brief paragraph or two). This introduction may be the same as the
first paragraph on the project page.

The purpose of this module is to simplify the display of node titles using a
language writing style guide such Associated Press (AP).

Apply a title case from a language style guide to selected content type page
titles. The Title Case module only alters the presentation display of the title
field and does not change the stored title field value.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/title_cases).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/title_cases).


## Table of contents (optional)

- Requirements
- Installation
- Configuration
- Troubleshooting
- Maintainers


## Requirements (required)

This module requires no modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration (required)

1. Enable the module at Administration > Extend.
1. Configure the Title Cases module at Administration > Configuration > System


## Troubleshooting (optional)

Displays a node title using a Title Case from the selected style guide after
configuration.

Block titles and Views field titles are not affected.

Drupal, browser, and other cache may need to be cleared.

## Maintainers (optional)

- Justin Christoffersen - [larsdesigns](https://www.drupal.org/u/larsdesigns)
